==> xwidgetsbase-9.1.9.tar.gz: lib/XMainDash_Base.dart <==
library dash;

import 'dart:async';
import 'dart:html';
import 'package:flutter/material.dart';
import 'package:provider/provider.dart';
import 'package:xtoolspackage/xtoolspackage.dart';

import 'XPlayer.dart';

class MainPageBase<T> extends StatefulWidget {
  MainPageBase(this.urlParams, this.liDash, {Key? key}) : super(key: key);
  String urlParams;
  List<XDashboard> liDash;
  @override
  _MainPageBaseState<T> createState() => _MainPageBaseState<T>();

  ///Configurazione FontSize per le Label delle Dash
  static double fontSizeForTitleOfDashBoard = 20;
  static double fontSizeForTitleOfArea = 19;
  static double fontSizeForSubTitleOfArea = 20;
  static double height_TitleContainerOfArea = 40;

  static Color appColor_AppName = Color.fromARGB(255, 56, 140, 250);
  static Color appColor_BackGroundDark = Color.fromARGB(255, 29, 29, 29);
  static Color appColor_BackGroundLight = Color.fromARGB(255, 251, 244, 244);
}

///Configurazione Altezze dei "Area_TitleContainer"

///Configurazione Colors dell' App

class _MainPageBaseState<T> extends State<MainPageBase<T>> {
  Timer? timerRefreshALL;
  Timer? timerRefresh_PWA;
  static List<int> liDashBoardIndexesDecodedFromURL = List<int>.empty(growable: true);
  static List<int> liDashBoardIndexesDecodedFromURL_timeOfView = List<int>.empty(growable: true);
  int defaultTimeOutForDash = 10;

  @override
  void initState() {
    //Settare quali Dashboard andranno visualizzate all'interno della liDashboard
    XPlayer.liXDashBoard.addAll(widget.liDash);

    ///Stabilisco quante Dash deve far vedere l'XPlayer e in che sequenza
    if (initMainDash() != null) {
      initMainDash();
    } else {
      // 1,3.30,0 >= la 1 per timeOut std, la 3 con timeOut 30sec, la 0
      var parts = widget.urlParams.split(',');
      print(parts);
      for (var dashCode in parts) {
        var timeOutDash = defaultTimeOutForDash;
        var idxDash = -1;
        var dashCodeParts = dashCode.split('.');
        print(dashCodeParts);

        if (dashCodeParts.length >= 1) {
          idxDash = int.parse(dashCodeParts[0]);
          if (dashCodeParts.length >= 2) timeOutDash = int.parse(dashCodeParts[1]);
        }
        if (idxDash >= 0) {
          liDashBoardIndexesDecodedFromURL.add(idxDash);
          liDashBoardIndexesDecodedFromURL_timeOfView.add(timeOutDash);
        }
      }
      //definisce elenco definitivo delle dash da visualizzare e apllica i timeOfView
      for (var i = 0; i < liDashBoardIndexesDecodedFromURL.length; i++) {
        XPlayer.liXDashBoard[liDashBoardIndexesDecodedFromURL[i]].timeOfView = liDashBoardIndexesDecodedFromURL_timeOfView[i];
      }
    }

    ///inserisco nella lista di Dash dell'XPlayer tutte le Dash che dovrò visualizzare
    init();
    super.initState();
  }

  Function()? initMainDash() {
    return null;
  }

  init() {
    // print("init() ${DateTime.now()}");
    refreshALL();

    ///chiamerà il refreshall ogni tot secondi che inserisci sotto
    timerRefreshALL = Timer.periodic(Duration(seconds: 10), (x) async => await refreshALL());
    // questo dovrebbe fare, insieme alle modifiche in index.html, scatenrare l'aggiornamento della PWA. FUNZIONA !!!!
    timerRefresh_PWA = Timer.periodic(Duration(hours: 1), (x) {
      //solo fuori da orari od'ufficio
      if (DateTime.now().hour < 7 || DateTime.now().hour == 13 || DateTime.now().hour > 18) window.location.reload();
    });
  }

  Future refreshALL() async {
    // print("refreshALL() ${DateTime.now()}");
  }

  @override
  Widget build(BuildContext context) {
    print("build() ${DateTime.now()}");
    return Consumer<T>(builder: (context, appState, _) {
      ///Ritorno l'XPlayer per Farmi gestire change dello screen e la lista delle Dash
      return Scaffold(backgroundColor: MainPageBase.appColor_BackGroundDark, body: XPlayer(liDashBoardIndexesDecodedFromURL));
    });
  }
}

==> xwidgetsbase-9.2.3.tar.gz: lib/XMainDash_Base.dart <==
library dash;

import 'dart:async';
import 'dart:html';
import 'package:flutter/material.dart';
import 'package:provider/provider.dart';
import 'package:xtoolspackage/xtoolspackage.dart';

import 'XPlayer.dart';

class MainDashBase<T> extends StatefulWidget {
  MainDashBase(this.urlParams, this.liDash, {Key? key}) : super(key: key);
  String urlParams;
  List<XDashboard> liDash = List<XDashboard>.empty(growable: true);
  @override
  State<MainDashBase<T>> createState() => MainDashBase_State<T>();

  ///Configurazione FontSize per le Label delle Dash
  static double fontSizeForTitleOfDashBoard = 20;
  static double fontSizeForTitleOfArea = 19;
  static double fontSizeForSubTitleOfArea = 20;
  static double height_TitleContainerOfArea = 40;

  ///Configurazione Altezze dei "Area_TitleContainer"
  static Color appColor_AppName = Color.fromARGB(255, 56, 140, 250);
  static Color appColor_BackGroundDark = Color.fromARGB(255, 29, 29, 29);
  static Color appColor_BackGroundLight = Color.fromARGB(255, 251, 244, 244);
}

///Configurazione Colors dell' App

class MainDashBase_State<T> extends State<MainDashBase<T>> {
  Timer? timerRefreshALL;
  Timer? timerRefresh_PWA;
  static List<int> liDashBoardIndexesDecodedFromURL = List<int>.empty(growable: true);
  static List<int> liDashBoardIndexesDecodedFromURL_timeOfView = List<int>.empty(growable: true);
  int defaultTimeOutForDash = 10;

  @override
  void initState() {
    //Settare quali Dashboard andranno visualizzate all'interno della liDashboard
    XPlayer.liXDashBoard.addAll(widget.liDash);

    ///Stabilisco quante Dash deve far vedere l'XPlayer e in che sequenza
    if (initMainDash() != null) {
      initMainDash();
    } else {
      // 1,3.30,0 >= la 1 per timeOut std, la 3 con timeOut 30sec, la 0
      var parts = widget.urlParams.split(',');
      print(parts);
      for (var dashCode in parts) {
        var timeOutDash = defaultTimeOutForDash;
        var idxDash = -1;
        var dashCodeParts = dashCode.split('.');
        print(dashCodeParts);

        if (dashCodeParts.length >= 1) {
          idxDash = int.parse(dashCodeParts[0]);
          if (dashCodeParts.length >= 2) timeOutDash = int.parse(dashCodeParts[1]);
        }
        if (idxDash >= 0) {
          liDashBoardIndexesDecodedFromURL.add(idxDash);
          liDashBoardIndexesDecodedFromURL_timeOfView.add(timeOutDash);
        }
      }
      //definisce elenco definitivo delle dash da visualizzare e apllica i timeOfView
      for (var i = 0; i < liDashBoardIndexesDecodedFromURL.length; i++) {
        XPlayer.liXDashBoard[liDashBoardIndexesDecodedFromURL[i]].timeOfView = liDashBoardIndexesDecodedFromURL_timeOfView[i];
      }
    }

    ///inserisco nella lista di Dash dell'XPlayer tutte le Dash che dovrò visualizzare
    init();
    super.initState();
  }

  Function()? initMainDash() {
    return null;
  }

  init() {
    // print("init() ${DateTime.now()}");
    refreshALL();

    ///chiamerà il refreshall ogni tot secondi che inserisci sotto
    timerRefreshALL = Timer.periodic(Duration(seconds: 10), (x) async => await refreshALL());
    // questo dovrebbe fare, insieme alle modifiche in index.html, scatenrare l'aggiornamento della PWA. FUNZIONA !!!!
    timerRefresh_PWA = Timer.periodic(Duration(hours: 1), (x) {
      //solo fuori da orari od'ufficio
      if (DateTime.now().hour < 7 || DateTime.now().hour == 13 || DateTime.now().hour > 18) window.location.reload();
    });
  }

  Future refreshALL() async {
    // print("refreshALL() ${DateTime.now()}");
  }

  @override
  Widget build(BuildContext context) {
    // print("build() ${DateTime.now()}");
    return Consumer<T>(builder: (context, appState, _) {
      ///Ritorno l'XPlayer per Farmi gestire change dello screen e la lista delle Dash
      return Scaffold(backgroundColor: MainDashBase.appColor_BackGroundDark, body: XPlayer(liDashBoardIndexesDecodedFromURL));
    });
  }
}
